Global - Nautobot Documentation

Skip to content

# Global

## Replace the Usage of Slugs

Slugs were used to identify unique objects in the database for various models in Nautobot v1.x and they are now replaced by Natural Keys. The `slug` field can be safely deleted as long as your models are derived from `BaseModel` that automatically supports the following natural key APIs. For a more comprehensive guideline on how Natural Keys in Nautobot v2.0 work, please go to the Natural Key documentation.